@@ -14,6 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 from botocore.paginate import Paginator as Boto3Paginator
 
@@ -58,14 +59,15 @@ class Exceptions:
 
 class BudgetsClient:
     """
-    [Budgets.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client)
+    [Budgets.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.can_paginate)
         """
 
     def create_budget(
@@ -75,7 +77,7 @@ class BudgetsClient:
         NotificationsWithSubscribers: List[NotificationWithSubscribersTypeDef] = None,
     ) -> Dict[str, Any]:
         """
-        [Client.create_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.create_budget)
+        [Client.create_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.create_budget)
         """
 
     def create_notification(
@@ -86,7 +88,7 @@ class BudgetsClient:
         Subscribers: List["SubscriberTypeDef"],
     ) -> Dict[str, Any]:
         """
-        [Client.create_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.create_notification)
+        [Client.create_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.create_notification)
         """
 
     def create_subscriber(
@@ -97,19 +99,19 @@ class BudgetsClient:
         Subscriber: "SubscriberTypeDef",
     ) -> Dict[str, Any]:
         """
-        [Client.create_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.create_subscriber)
+        [Client.create_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.create_subscriber)
         """
 
     def delete_budget(self, AccountId: str, BudgetName: str) -> Dict[str, Any]:
         """
-        [Client.delete_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.delete_budget)
+        [Client.delete_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.delete_budget)
         """
 
     def delete_notification(
         self, AccountId: str, BudgetName: str, Notification: "NotificationTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Client.delete_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.delete_notification)
+        [Client.delete_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.delete_notification)
         """
 
     def delete_subscriber(
@@ -120,12 +122,12 @@ class BudgetsClient:
         Subscriber: "SubscriberTypeDef",
     ) -> Dict[str, Any]:
         """
-        [Client.delete_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.delete_subscriber)
+        [Client.delete_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.delete_subscriber)
         """
 
     def describe_budget(self, AccountId: str, BudgetName: str) -> DescribeBudgetResponseTypeDef:
         """
-        [Client.describe_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.describe_budget)
+        [Client.describe_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.describe_budget)
         """
 
     def describe_budget_performance_history(
@@ -137,21 +139,21 @@ class BudgetsClient:
         NextToken: str = None,
     ) -> DescribeBudgetPerformanceHistoryResponseTypeDef:
         """
-        [Client.describe_budget_performance_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.describe_budget_performance_history)
+        [Client.describe_budget_performance_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.describe_budget_performance_history)
         """
 
     def describe_budgets(
         self, AccountId: str, MaxResults: int = None, NextToken: str = None
     ) -> DescribeBudgetsResponseTypeDef:
         """
-        [Client.describe_budgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.describe_budgets)
+        [Client.describe_budgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.describe_budgets)
         """
 
     def describe_notifications_for_budget(
         self, AccountId: str, BudgetName: str, MaxResults: int = None, NextToken: str = None
     ) -> DescribeNotificationsForBudgetResponseTypeDef:
         """
-        [Client.describe_notifications_for_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.describe_notifications_for_budget)
+        [Client.describe_notifications_for_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.describe_notifications_for_budget)
         """
 
     def describe_subscribers_for_notification(
@@ -163,7 +165,7 @@ class BudgetsClient:
         NextToken: str = None,
     ) -> DescribeSubscribersForNotificationResponseTypeDef:
         """
-        [Client.describe_subscribers_for_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.describe_subscribers_for_notification)
+        [Client.describe_subscribers_for_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.describe_subscribers_for_notification)
         """
 
     def generate_presigned_url(
@@ -174,12 +176,12 @@ class BudgetsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.generate_presigned_url)
         """
 
     def update_budget(self, AccountId: str, NewBudget: "BudgetTypeDef") -> Dict[str, Any]:
         """
-        [Client.update_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.update_budget)
+        [Client.update_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.update_budget)
         """
 
     def update_notification(
@@ -190,7 +192,7 @@ class BudgetsClient:
         NewNotification: "NotificationTypeDef",
     ) -> Dict[str, Any]:
         """
-        [Client.update_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.update_notification)
+        [Client.update_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.update_notification)
         """
 
     def update_subscriber(
@@ -202,7 +204,7 @@ class BudgetsClient:
         NewSubscriber: "SubscriberTypeDef",
     ) -> Dict[str, Any]:
         """
-        [Client.update_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Client.update_subscriber)
+        [Client.update_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.update_subscriber)
         """
 
     @overload
@@ -210,7 +212,7 @@ class BudgetsClient:
         self, operation_name: Literal["describe_budgets"]
     ) -> DescribeBudgetsPaginator:
         """
-        [Paginator.DescribeBudgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
+        [Paginator.DescribeBudgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
         """
 
     @overload
@@ -218,7 +220,7 @@ class BudgetsClient:
         self, operation_name: Literal["describe_notifications_for_budget"]
     ) -> DescribeNotificationsForBudgetPaginator:
         """
-        [Paginator.DescribeNotificationsForBudget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
+        [Paginator.DescribeNotificationsForBudget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
         """
 
     @overload
@@ -226,7 +228,7 @@ class BudgetsClient:
         self, operation_name: Literal["describe_subscribers_for_notification"]
     ) -> DescribeSubscribersForNotificationPaginator:
         """
-        [Paginator.DescribeSubscribersForNotification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
+        [Paginator.DescribeSubscribersForNotification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
         """
 
     def get_paginator(self, operation_name: str) -> Boto3Paginator:
